@@ -104,9 +104,9 @@
   (milli [this]   "Return the millisecond of second component of the given date/time.")
   (after? [this that] "Returns true if ReadableDateTime 'this' is strictly after date/time 'that'.")
   (before? [this that] "Returns true if ReadableDateTime 'this' is strictly before date/time 'that'.")
-  (plus- [this #^ReadablePeriod period]
+  (plus- [this ^ReadablePeriod period]
     "Returns a new date/time corresponding to the given date/time moved forwards by the given Period(s).")
-  (minus- [this #^ReadablePeriod period]
+  (minus- [this ^ReadablePeriod period]
     "Returns a new date/time corresponding to the given date/time moved backwards by the given Period(s)."))
 
 (extend-protocol DateTimeProtocol
@@ -118,14 +118,15 @@
   (hour [this] (.getHourOfDay this))
   (minute [this] (.getMinuteOfHour this))
   (sec [this]
+    {:deprecated "0.6.0"}
     (deprecated "sec is being deprecated in favor of second")
     (.getSecondOfMinute this))
   (second [this] (.getSecondOfMinute this))
   (milli [this] (.getMillisOfSecond this))
-  (after? [this #^ReadableInstant that] (.isAfter this that))
-  (before? [this #^ReadableInstant that] (.isBefore this that))
-  (plus- [this #^ReadablePeriod period] (.plus this period))
-  (minus- [this #^ReadablePeriod period] (.minus this period))
+  (after? [this ^ReadableInstant that] (.isAfter this that))
+  (before? [this ^ReadableInstant that] (.isBefore this that))
+  (plus- [this ^ReadablePeriod period] (.plus this period))
+  (minus- [this ^ReadablePeriod period] (.minus this period))
 
   org.joda.time.DateMidnight
   (year [this] (.getYear this))
@@ -135,14 +136,15 @@
   (hour [this] (.getHourOfDay this))
   (minute [this] (.getMinuteOfHour this))
   (sec [this]
+    {:deprecated "0.6.0"}
     (deprecated "sec is being deprecated in favor of second")
     (.getSecondOfMinute this))
   (second [this] (.getSecondOfMinute this))
   (milli [this] (.getMillisOfSecond this))
-  (after? [this #^ReadableInstant that] (.isAfter this that))
-  (before? [this #^ReadableInstant that] (.isBefore this that))
-  (plus- [this #^ReadablePeriod period] (.plus this period))
-  (minus- [this #^ReadablePeriod period] (.minus this period))
+  (after? [this ^ReadableInstant that] (.isAfter this that))
+  (before? [this ^ReadableInstant that] (.isBefore this that))
+  (plus- [this ^ReadablePeriod period] (.plus this period))
+  (minus- [this ^ReadablePeriod period] (.minus this period))
 
   org.joda.time.LocalDateTime
   (year [this] (.getYear this))
@@ -152,32 +154,33 @@
   (hour [this] (.getHourOfDay this))
   (minute [this] (.getMinuteOfHour this))
   (sec [this]
+    {:deprecated "0.6.0"}
     (deprecated "sec is being deprecated in favor of second")
     (.getSecondOfMinute this))
   (second [this] (.getSecondOfMinute this))
   (milli [this] (.getMillisOfSecond this))
-  (after? [this #^ReadablePartial that] (.isAfter this that))
-  (before? [this #^ReadablePartial that] (.isBefore this that))
-  (plus- [this #^ReadablePeriod period] (.plus this period))
-  (minus- [this #^ReadablePeriod period] (.minus this period))
+  (after? [this ^ReadablePartial that] (.isAfter this that))
+  (before? [this ^ReadablePartial that] (.isBefore this that))
+  (plus- [this ^ReadablePeriod period] (.plus this period))
+  (minus- [this ^ReadablePeriod period] (.minus this period))
 
   org.joda.time.YearMonth
   (year [this] (.getYear this))
   (month [this] (.getMonthOfYear this))
-  (after? [this #^ReadablePartial that] (.isAfter this that))
-  (before? [this #^ReadablePartial that] (.isBefore this that))
-  (plus- [this #^ReadablePeriod period] (.plus this period))
-  (minus- [this #^ReadablePeriod period] (.minus this period))
+  (after? [this ^ReadablePartial that] (.isAfter this that))
+  (before? [this ^ReadablePartial that] (.isBefore this that))
+  (plus- [this ^ReadablePeriod period] (.plus this period))
+  (minus- [this ^ReadablePeriod period] (.minus this period))
 
   org.joda.time.LocalDate
   (year [this] (.getYear this))
   (month [this] (.getMonthOfYear this))
   (day [this] (.getDayOfMonth this))
   (day-of-week [this] (.getDayOfWeek this))
-  (after? [this #^ReadablePartial that] (.isAfter this that))
-  (before? [this #^ReadablePartial that] (.isBefore this that))
-  (plus- [this #^ReadablePeriod period] (.plus this period))
-  (minus- [this #^ReadablePeriod period] (.minus this period)))
+  (after? [this ^ReadablePartial that] (.isAfter this that))
+  (before? [this ^ReadablePartial that] (.isBefore this that))
+  (plus- [this ^ReadablePeriod period] (.plus this period))
+  (minus- [this ^ReadablePeriod period] (.minus this period)))
 
 (def ^{:doc "DateTimeZone for UTC."}
       utc
@@ -186,17 +189,19 @@
 (defn now
   "Returns a DateTime for the current instant in the UTC time zone."
   []
-  (DateTime. #^DateTimeZone utc))
+  (DateTime. ^DateTimeZone utc))
 
 (defn today-at-midnight
   "Returns a DateMidnight for today at midnight in the UTC time zone."
-  []
-  (DateMidnight. #^DateTimeZone utc))
+  ([]
+   (DateMidnight. ^DateTimeZone utc))
+  ([^DateTimeZone tz]
+   (DateMidnight. tz)))
 
 (defn epoch
   "Returns a DateTime for the begining of the Unix epoch in the UTC time zone."
   []
-  (DateTime. (long 0) #^DateTimeZone utc))
+  (DateTime. (long 0) ^DateTimeZone utc))
 
 (defn date-midnight
   "Constructs and returns a new DateMidnight in UTC.
@@ -208,7 +213,7 @@
   ([^long year ^long month]
     (date-midnight year month 1))
   ([^Long year ^Long month ^Long day]
-    (DateMidnight. year month day #^DateTimeZone utc)))
+    (DateMidnight. year month day ^DateTimeZone utc)))
 
 (defn ^DateTime date-time
   "Constructs and returns a new DateTime in UTC.
@@ -229,11 +234,11 @@
    (date-time year month day hour minute 0 0))
   ([year month day hour minute second]
    (date-time year month day hour minute second 0))
-  ([#^Integer year #^Integer month #^Integer day #^Integer hour
-    #^Integer minute #^Integer second #^Integer millis]
-   (DateTime. year month day hour minute second millis #^DateTimeZone utc)))
+  ([^Integer year ^Integer month ^Integer day ^Integer hour
+    ^Integer minute ^Integer second ^Integer millis]
+   (DateTime. year month day hour minute second millis ^DateTimeZone utc)))
 
-(defn #^org.joda.time.LocalDateTime local-date-time
+(defn ^org.joda.time.LocalDateTime local-date-time
   "Constructs and returns a new LocalDateTime.
    Specify the year, month of year, day of month, hour of day, minute if hour,
    second of minute, and millisecond of second. Note that month and day are
@@ -252,26 +257,26 @@
    (local-date-time year month day hour minute 0 0))
   ([year month day hour minute second]
    (local-date-time year month day hour minute second 0))
-  ([#^Integer year #^Integer month #^Integer day #^Integer hour
-    #^Integer minute #^Integer second #^Integer millis]
+  ([^Integer year ^Integer month ^Integer day ^Integer hour
+    ^Integer minute ^Integer second ^Integer millis]
    (LocalDateTime. year month day hour minute second millis)))
 
-(defn #^org.joda.time.YearMonth year-month
+(defn ^org.joda.time.YearMonth year-month
   "Constructs and returns a new YearMonth.
    Specify the year and month of year. Month is 1-indexed and defaults
    to January (1)."
   ([year]
      (year-month year 1))
-  ([#^Integer year #^Integer month]
+  ([^Integer year ^Integer month]
      (YearMonth. year month)))
 
-(defn #^org.joda.time.LocalDate local-date
+(defn ^org.joda.time.LocalDate local-date
   "Constructs and returns a new LocalDate.
    Specify the year, month, and day. Does not deal with timezones."
-  [#^Integer year #^Integer month #^Integer day]
+  [^Integer year ^Integer month ^Integer day]
   (LocalDate. year month day))
 
-(defn #^org.joda.time.LocalDate today
+(defn ^org.joda.time.LocalDate today
   "Constructs and returns a new LocalDate representing today's date.
    LocalDate objects do not deal with timezones at all."
   []
@@ -288,7 +293,7 @@
 (defn time-zone-for-id
   "Returns a DateTimeZone for the given ID, which must be in long form, e.g.
    'America/Matamoros'."
-  [#^String id]
+  [^String id]
   (DateTimeZone/forID id))
 
 (defn default-time-zone
@@ -296,20 +301,20 @@
   []
   (DateTimeZone/getDefault))
 
-(defn #^org.joda.time.DateTime
+(defn ^org.joda.time.DateTime
   to-time-zone
   "Returns a new ReadableDateTime corresponding to the same absolute instant in time as
    the given ReadableDateTime, but with calendar fields corresponding to the given
    TimeZone."
-  [#^DateTime dt #^DateTimeZone tz]
+  [^DateTime dt ^DateTimeZone tz]
   (.withZone dt tz))
 
-(defn #^org.joda.time.DateTime
+(defn ^org.joda.time.DateTime
   from-time-zone
   "Returns a new ReadableDateTime corresponding to the same point in calendar time as
    the given ReadableDateTime, but for a correspondingly different absolute instant in
    time."
-  [#^DateTime dt #^DateTimeZone tz]
+  [^DateTime dt ^DateTimeZone tz]
   (.withZoneRetainFields dt tz))
 
 (defn years
@@ -317,7 +322,7 @@
    Without an argument, returns a PeriodType representing only years."
   ([]
      (PeriodType/years))
-  ([#^Integer n]
+  ([^Integer n]
      (Years/years n)))
 
 (defn months
@@ -325,7 +330,7 @@
    Without an argument, returns a PeriodType representing only months."
   ([]
      (PeriodType/months))
-  ([#^Integer n]
+  ([^Integer n]
      (Months/months n)))
 
 (defn weeks
@@ -333,7 +338,7 @@
    Without an argument, returns a PeriodType representing only weeks."
   ([]
      (PeriodType/weeks))
-  ([#^Integer n]
+  ([^Integer n]
      (Weeks/weeks n)))
 
 (defn days
@@ -341,7 +346,7 @@
    Without an argument, returns a PeriodType representing only days."
   ([]
      (PeriodType/days))
-  ([#^Integer n]
+  ([^Integer n]
      (Days/days n)))
 
 (defn hours
@@ -349,7 +354,7 @@
    Without an argument, returns a PeriodType representing only hours."
   ([]
      (PeriodType/hours))
-  ([#^Integer n]
+  ([^Integer n]
      (Hours/hours n)))
 
 (defn minutes
@@ -357,7 +362,7 @@
    Without an argument, returns a PeriodType representing only minutes."
   ([]
      (PeriodType/minutes))
-  ([#^Integer n]
+  ([^Integer n]
      (Minutes/minutes n)))
 
 (defn seconds
@@ -365,14 +370,17 @@
    Without an argument, returns a PeriodType representing only seconds."
   ([]
      (PeriodType/seconds))
-  ([#^Integer n]
+  ([^Integer n]
      (Seconds/seconds n)))
 
 (defn secs
   "DEPRECATED"
+  {:deprecated "0.6.0"}
   ([]
+     (deprecated "secs has been deprecated in favor of seconds")
      (seconds))
-  ([#^Integer n]
+  ([^Integer n]
+     (deprecated "secs has been deprecated in favor of seconds")
      (seconds n)))
 
 (defn millis
@@ -380,13 +388,13 @@
    Without an argument, returns a PeriodType representing only milliseconds."
   ([]
      (PeriodType/millis))
-  ([#^Integer n]
+  ([^Integer n]
      (Period/millis n)))
 
 (defn plus
   "Returns a new date/time corresponding to the given date/time moved forwards by
    the given Period(s)."
-  ([dt #^ReadablePeriod p]
+  ([dt ^ReadablePeriod p]
      (plus- dt p))
   ([dt p & ps]
      (reduce plus- (plus- dt p) ps)))
@@ -394,7 +402,7 @@
 (defn minus
   "Returns a new date/time object corresponding to the given date/time moved backwards by
    the given Period(s)."
-  ([dt #^ReadablePeriod p]
+  ([dt ^ReadablePeriod p]
    (minus- dt p))
   ([dt p & ps]
      (reduce minus- (minus- dt p) ps)))
@@ -402,87 +410,105 @@
 (defn ago
   "Returns a DateTime a supplied period before the present.
   e.g. (-> 5 years ago)"
-  [#^Period period]
+  [^Period period]
   (minus (now) period))
 
 (defn from-now
   "Returns a DateTime a supplied period after the present.
   e.g. (-> 30 minutes from-now)"
-  [#^Period period]
+  [^Period period]
   (plus (now) period))
 
+(defn earliest
+  "Returns the earliest of the supplied DateTimes"
+  ([^ReadableInstant dt1 ^ReadableInstant dt2]
+     (if (pos? (compare dt1 dt2)) dt2 dt1))
+  ([dts]
+     (reduce (fn [dt1 dt2]
+               (if (pos? (compare dt1 dt2)) dt2 dt1)) dts)))
+
+(defn latest
+  "Returns the latest of the supplied DateTimes"
+  ([^ReadableInstant dt1 ^ReadableInstant dt2]
+     (if (neg? (compare dt1 dt2)) dt2 dt1))
+  ([dts]
+     (reduce (fn [dt1 dt2]
+               (if (neg? (compare dt1 dt2)) dt2 dt1)) dts)))
+
 (defn interval
   "Returns an interval representing the span between the two given ReadableDateTimes.
    Note that intervals are closed on the left and open on the right."
-  [#^ReadableDateTime dt-a #^ReadableDateTime dt-b]
+  [^ReadableDateTime dt-a ^ReadableDateTime dt-b]
   (Interval. dt-a dt-b))
 
 (defn start
   "Returns the start DateTime of an Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getStart in))
 
 (defn end
   "Returns the end DateTime of an Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getEnd in))
 
 (defn extend
   "Returns an Interval with an end ReadableDateTime the specified Period after the end
    of the given Interval"
-  [#^Interval in & by]
+  [^Interval in & by]
   (.withEnd in (apply plus (end in) by)))
 
 (defn in-millis
   "Returns the number of milliseconds in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.toDurationMillis in))
 
 (defn in-msecs
   "DEPRECATED: Returns the number of milliseconds in the given Interval."
-  [#^Interval in]
-  (deprecated "DEPRECATED: use in-millis")
+  {:deprecated "0.6.0"}
+  [^Interval in]
+  (deprecated "in-msecs has been deprecated in favor of in-millis")
   (in-millis in))
 
 (defn in-seconds
   "Returns the number of standard seconds in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getSeconds (.toPeriod in (seconds))))
 
 (defn in-secs
   "DEPRECATED: Returns the number of standard seconds in the given Interval."
-  [#^Interval in]
-  (deprecated "Please use in-seconds instead.")
+  {:deprecated "0.6.0"}
+  [^Interval in]
+  (deprecated "in-secs has been deprecated in favor of in-seconds")
   (in-seconds in))
 
 (defn in-minutes
   "Returns the number of standard minutes in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getMinutes (.toPeriod in (minutes))))
 
 (defn in-hours
   "Returns the number of standard hours in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getHours (.toPeriod in (hours))))
 
 (defn in-days
   "Returns the number of standard days in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getDays (.toPeriod in (days))))
 
 (defn in-weeks
   "Returns the number of standard weeks in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getWeeks (.toPeriod in (weeks))))
 
 (defn in-months
   "Returns the number of standard months in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getMonths (.toPeriod in (months))))
 
 (defn in-years
   "Returns the number of standard years in the given Interval."
-  [#^Interval in]
+  [^Interval in]
   (.getYears (.toPeriod in (years))))
 
 (defn within?
@@ -492,9 +518,9 @@
    With 3 arguments: Returns true if the start ReadablePartial is
    equal to or before and the end ReadablePartial is equal to or after the test
    ReadablePartial."
-  ([#^Interval i #^ReadableDateTime dt]
+  ([^Interval i ^ReadableDateTime dt]
      (.contains i dt))
-  ([#^ReadablePartial start #^ReadablePartial end #^ReadablePartial test]
+  ([^ReadablePartial start ^ReadablePartial end ^ReadablePartial test]
      (or (= start test)
          (= end test)
          (and (before? start test) (after? end test)))))
@@ -504,10 +530,10 @@
    Note that intervals that satisfy abuts? do not satisfy overlaps?
    With 4 arguments: Returns true if the range specified by start-a and end-a
    overlaps with the range specified by start-b and end-b."
-  ([#^Interval i-a #^Interval i-b]
+  ([^Interval i-a ^Interval i-b]
      (.overlaps i-a i-b))
-  ([#^ReadablePartial start-a #^ReadablePartial end-a
-    #^ReadablePartial start-b #^ReadablePartial end-b]
+  ([^ReadablePartial start-a ^ReadablePartial end-a
+    ^ReadablePartial start-b ^ReadablePartial end-b]
      (or (and (before? start-b end-a) (after? end-b start-a))
          (and (after? end-b start-a) (before? start-b end-a))
          (or (= start-a end-b) (= start-b end-a)))))
@@ -515,7 +541,7 @@
 (defn abuts?
   "Returns true if Interval i-a abuts i-b, i.e. then end of i-a is exactly the
    beginning of i-b."
-  [#^Interval i-a #^Interval i-b]
+  [^Interval i-a ^Interval i-b]
   (.abuts i-a i-b))
 
 (defn years?
@@ -555,8 +581,9 @@
 
 (defn secs?
   "DEPRECATED"
+  {:deprecated "0.6.0"}
   [val]
-  (deprecated "Please use seconds? instead.")
+  (deprecated "secs? has been deprecated in favor of seconds?")
   (seconds? val))
 
 (defn mins-ago
