@@ -11,6 +11,7 @@ fi
 prefix=${prefix:=/usr}
 initdir=${initdir:=/etc/init.d}
 unitdir=${unitdir:=/usr/lib/systemd/system}
+tmpfilesdir=${tmpfilesdir:=/usr/lib/tmpfiles.d}
 datadir=${datadir:=${prefix}/share}
 real_name=${real_name:=puppetserver}
 projdatadir=${projdatadir:=${datadir}/${real_name}}
@@ -23,11 +24,11 @@ bindir=${bindir:=/opt/puppetlabs/server/apps/${real_name}/bin}
 uxbindir=${uxbindir:=/opt/puppetlabs/bin}
 # symlinks of server binaries
 symbindir=${symbindir:=/opt/puppetlabs/server/bin}
-localstatedir=${localstatedir:=/var}
 app_prefix=${app_prefix:=/opt/puppetlabs/server/apps/${real_name}}
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
 
+
 ##################
 # EZBake Vars    #
 ##################
@@ -113,7 +114,7 @@ function task_install {
     install -d -m 0755 "${DESTDIR}${app_prefix}"
     install -d -m 0755 "${DESTDIR}${app_data}"
     install -m 0644 puppet-server-release.jar "${DESTDIR}${app_prefix}"
-    install -m 0774 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
+    install -m 0750 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
     install -m 0644 ext/ezbake.manifest "${DESTDIR}${app_prefix}"
     install -d -m 0755 "${DESTDIR}${projconfdir}/conf.d"
     install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
@@ -174,7 +175,9 @@ function task_sysv_init_suse {
 function task_systemd_redhat {
     task defaults
     install -d -m 0755 "${DESTDIR}${unitdir}"
-    install -m 0755 ext/redhat/puppetserver.service "${DESTDIR}${unitdir}/puppetserver.service"
+    install -m 0644 ext/redhat/puppetserver.service "${DESTDIR}${unitdir}/puppetserver.service"
+    install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
+    install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
 }
 
 # Install the sysv and defaults configuration for Debian.
@@ -185,18 +188,26 @@ function task_sysv_init_deb {
     install -d -m 0755 "${DESTDIR}${rundir}"
 }
 
+function task_service_account {
+    # Add puppet group
+    getent group puppet > /dev/null || \
+        groupadd -r puppet || :
+    # Add or update puppet user
+    if getent passwd puppet > /dev/null; then
+        usermod --gid puppet --home "${app_data}" \
+            --comment "puppetserver daemon" puppet || :
+    else
+        useradd -r --gid puppet --home "${app_data}" --shell $(which nologin) \
+            --comment "puppetserver daemon"  puppet || :
+    fi
+}
+
 # RPM based pre-installation tasks.
 # Note: Any changes to this section may require synchronisation with the
 # packaging, due to the fact that we can't access this script from the pre
 # section of an rpm/deb.
 function task_preinst_redhat {
-    # Add puppet group
-    getent group puppet > /dev/null || \
-           groupadd -r puppet || :
-    # Add puppet user
-    getent passwd puppet > /dev/null || \
-           useradd -r -g puppet -d "${app_data}" -s /sbin/nologin \
-           -c "puppetserver daemon"  puppet || :
+    task service_account
 }
 
 # Debian based pre-installation tasks.
@@ -204,20 +215,7 @@ function task_preinst_redhat {
 # packaging, due to the fact that we can't access this script from the pre
 # section of an rpm/deb.
 function task_preinst_deb {
-    # Create the "puppet" user
-    if ! getent passwd puppet > /dev/null; then
-        adduser --quiet --system --group --home "${app_data}"  \
-        --no-create-home                                 \
-        --gecos "puppetserver daemon" \
-        puppet ; \
-    fi
-
-    # Create the "puppet" group, if it is missing, and set the
-    # primary group of the "puppet" user to this group.
-    if ! getent group puppet > /dev/null; then
-        addgroup --quiet --system puppet; \
-        usermod -g puppet puppet; \
-    fi
+    task service_account
 }
 
 # Debian based post-installation tasks.
@@ -259,7 +257,7 @@ function task_postinst_permissions {
     chown puppet:puppet /var/log/puppetlabs/puppetserver
     chmod 700 /var/log/puppetlabs/puppetserver
     chown puppet:puppet $app_data
-    chmod 775 $app_data
+    chmod 770 $app_data
 }
 
 # Install logrotate (usually el7, fedora 16 and above)
