@@ -1,4 +1,4 @@
-(defproject clj-time/clj-time "0.6.0"
+(defproject clj-time/clj-time "0.7.0"
   :description "A date and time library for Clojure, wrapping Joda Time."
   :url "https://github.com/clj-time/clj-time"
   :mailing-list {:name "clj-time mailing list"
@@ -7,12 +7,14 @@
   :license {:name "MIT License"
             :url "http://www.opensource.org/licenses/mit-license.php"
             :distribution :repo}
-  :dependencies [[joda-time "2.2"] [org.clojure/clojure "1.5.1"]]
+  :dependencies [[joda-time "2.3"] [org.clojure/clojure "1.6.0"]]
   :min-lein-version "2.0.0"
   :profiles {:dev {:plugins [[codox "0.6.1"]]}
              :1.2 {:dependencies [[org.clojure/clojure "1.2.1"]]}
              :1.3 {:dependencies [[org.clojure/clojure "1.3.0"]]}
              :1.4 {:dependencies [[org.clojure/clojure "1.4.0"]]}
-             :1.6 {:repositories [["snapshots" "https://oss.sonatype.org/content/repositories/snapshots/"]]
-                   :dependencies [[org.clojure/clojure "1.6.0-master-SNAPSHOT"]]}}
-  :aliases {"test-all" ["with-profile" "dev,default:dev,1.2,default:dev,1.3,default:dev,1.4,default:dev,1.6,default" "test"]})
+             :1.5 {:repositories [["snapshots" "https://oss.sonatype.org/content/repositories/snapshots/"]]
+                   :dependencies [[org.clojure/clojure "1.5.1"]]}
+             :master {:repositories [["snapshots" "https://oss.sonatype.org/content/repositories/snapshots/"]]
+                   :dependencies [[org.clojure/clojure "1.7.0-master-SNAPSHOT"]]}}
+  :aliases {"test-all" ["with-profile" "dev,default:dev,1.2,default:dev,1.3,default:dev,1.4,default:dev,1.5,default:dev,master,default" "test"]})
