@@ -487,6 +487,35 @@
               "No exception thrown even though no file existed for copying")
           (fs/copy copy cacert))))))
 
+(deftest retrieve-ca-crl!-test
+  (testing "CRL file copied when it doesn't already exist"
+    (let [tmp-confdir (fs/copy-dir confdir (ks/temp-dir))
+          settings    (testutils/master-settings tmp-confdir)
+          ca-settings (testutils/ca-settings (str tmp-confdir "/ssl/ca"))
+          cacrl       (:cacrl ca-settings)
+          hostcrl     (:hostcrl settings)
+          cacrl-text (slurp cacrl)]
+
+      (testing "Copied cacrl to hostcrl when hostcrl not present"
+        (retrieve-ca-crl! cacrl hostcrl)
+        (is (= (slurp hostcrl) cacrl-text)
+            (str "Unexpected content for hostcrl: " hostcrl)))
+
+      (testing "Copied cacrl to hostcrl when different hostcrl present"
+        (spit (:hostcrl settings) "12345")
+        (retrieve-ca-crl! cacrl hostcrl)
+        (is (= (slurp hostcrl) cacrl-text)
+            (str "Unexpected content for hostcrl: " hostcrl)))
+
+      (testing (str "Doesn't throw exception or create dummy file if no "
+                    "hostcrl and no cacrl to copy")
+        (fs/delete hostcrl)
+        (let [copy (fs/copy cacrl (ks/temp-file))]
+          (fs/delete cacrl)
+          (is (not (fs/exists? hostcrl))
+              "hostcrl file present even though no file existed for copying")
+          (fs/copy copy cacrl))))))
+
 (deftest initialize-master-ssl!-test
   (let [tmp-confdir (fs/copy-dir confdir (ks/temp-dir))
         settings    (-> (testutils/master-settings tmp-confdir "master")
@@ -494,6 +523,7 @@
         ca-settings (testutils/ca-settings (str tmp-confdir "/ssl/ca"))]
 
     (retrieve-ca-cert! (:cacert ca-settings) (:localcacert settings))
+    (retrieve-ca-crl! (:cacrl ca-settings) (:hostcrl settings))
     (initialize-master-ssl! settings "master" ca-settings)
 
     (testing "Generated SSL file"
@@ -587,6 +617,44 @@
         #".*RSA keys must be no longer than 16384 bits.*"
           (initialize-master-ssl! (assoc settings :keylength 32768) "master" ca-settings))))))
 
+(deftest initialize-master-ssl!-test-with-keylength-settings
+  (let [tmp-confdir (fs/copy-dir confdir (ks/temp-dir))
+        settings (-> (testutils/master-settings tmp-confdir)
+                     (assoc :keylength 768))
+        ca-settings (assoc (testutils/ca-settings (str tmp-confdir "/ssl/ca")) :keylength 768)]
+
+  (retrieve-ca-cert! (:cacert ca-settings) (:localcacert settings))
+  (initialize-master-ssl! settings "master" ca-settings)
+
+  (testing "hostprivkey should have correct keylength"
+    (let [key (-> settings :hostprivkey utils/pem->private-key)]
+      (is (utils/private-key? key))
+      (is (= 768 (utils/keylength key)))))
+
+  (testing "hostpubkey should have correct keylength"
+    (let [key (-> settings :hostpubkey utils/pem->public-key)]
+      (is (utils/public-key? key))
+      (is (= 768 (utils/keylength key)))))))
+
+(deftest initialize-master-ssl!-test-with-incorrect-keylength
+  (let [tmp-confdir (fs/copy-dir confdir (ks/temp-dir))
+        settings (testutils/master-settings tmp-confdir)
+        ca-settings (testutils/ca-settings (str tmp-confdir "/ssl/ca"))]
+
+    (retrieve-ca-cert! (:cacert ca-settings) (:localcacert settings))
+
+    (testing "should throw an error message with too short keylength"
+      (is (thrown-with-msg?
+        InvalidParameterException
+        #".*RSA keys must be at least 512 bits long.*"
+          (initialize-master-ssl! (assoc settings :keylength 128) "master" ca-settings))))
+
+    (testing "should throw an error message with too large keylength"
+      (is (thrown-with-msg?
+        InvalidParameterException
+        #".*RSA keys must be no longer than 16384 bits.*"
+          (initialize-master-ssl! (assoc settings :keylength 32768) "master" ca-settings))))))
+
 (deftest parse-serial-number-test
   (is (= (parse-serial-number "0001") 1))
   (is (= (parse-serial-number "0010") 16))
@@ -915,7 +983,7 @@
                             :value    {:dns-name ["subject"
                                                   "onefish"
                                                   "twofish"]}}
-                           ;; These extensions come form the csr_attributes.yaml file
+                           ;; These extensions come form csr_attributes.yaml
                            {:oid      "1.3.6.1.4.1.34380.1.1.1"
                             :critical false
                             :value    "ED803750-E3C7-44F5-BB08-41A04433FE2E"}
@@ -930,7 +998,33 @@
                             :value    "my_ami_image"}
                            {:oid      "1.3.6.1.4.1.34380.1.1.4"
                             :critical false
-                            :value    "342thbjkt82094y0uthhor289jnqthpc2290"}]]
+                            :value    "342thbjkt82094y0uthhor289jnqthpc2290"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.5" :critical false
+                            :value    "center"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.6" :critical false
+                            :value    "product"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.7" :critical false
+                            :value    "project"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.8" :critical false
+                            :value    "application"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.9" :critical false
+                            :value    "service"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.10" :critical false
+                            :value    "employee"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.11" :critical false
+                            :value    "created"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.12" :critical false
+                            :value    "environment"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.13" :critical false
+                            :value    "role"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.14" :critical false
+                            :value    "version"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.15" :critical false
+                            :value    "deparment"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.16" :critical false
+                            :value    "cluster"}
+                           {:oid      "1.3.6.1.4.1.34380.1.1.17" :critical false
+                            :value    "provisioner"}]]
         (is (= (set exts) (set exts-expected)))))
 
     (testing "A non-puppet OID read from a CSR attributes file is rejected"
