@@ -19,10 +19,13 @@
       (is (thrown-with-msg? ExceptionInfo
                             #"Input to create-pool-context does not match schema"
                             (jruby-core/create-pool-context malformed-config nil nil)))))
-  (let [minimal-config {:jruby-puppet {:gem-home "/dev/null"
+  (let [minimal-config {:jruby-puppet {:gem-home        "/dev/null"
                                        :master-conf-dir "/dev/null"
-                                       :master-var-dir "/dev/null"}
-                        :os-settings  {:ruby-load-path ["/dev/null"]}}
+                                       :master-var-dir  "/dev/null"
+                                       :master-code-dir "/dev/null"
+                                       :master-log-dir  "/dev/null"
+                                       :master-run-dir  "/dev/null"
+                                       :ruby-load-path  ["/dev/null"]}}
         config        (jruby-core/initialize-config minimal-config)]
     (testing "max-active-instances is set to default if not specified"
       (is (= (jruby-core/default-pool-size (ks/num-cpus)) (:max-active-instances config))))
@@ -145,16 +148,12 @@
       (let [instance (jruby-core/borrow-from-pool pool-context :test [])]
         (is (= id (:id instance))))))
   (testing "JRuby instance is flushed after exceeding max requests"
-    (let [pool-context  (create-pool-context 1)]
-      (is (= 1 (count (jruby-core/registered-instances pool-context))))
-      (let [instance (jruby-core/borrow-from-pool pool-context :test [])
-            id (:id instance)]
-        (jruby-core/return-to-pool instance :test [])
-        (let [instance (jruby-core/borrow-from-pool pool-context :test [])]
-          (is (not= id (:id instance))))
-        (testing "instance is removed from registered elements after flushing"
-          (is (= 1 (count (jruby-core/registered-instances pool-context))))))))
-
+    (let [pool-context  (create-pool-context 1)
+          instance      (jruby-core/borrow-from-pool pool-context :test [])
+          id            (:id instance)]
+      (jruby-core/return-to-pool instance :test [])
+      (let [instance (jruby-core/borrow-from-pool pool-context :test [])]
+        (is (not= id (:id instance))))))
   (testing "JRuby instance is not flushed if max requests setting is set to 0"
     (let [pool-context  (create-pool-context 0)
           instance      (jruby-core/borrow-from-pool pool-context :test [])
