@@ -4,7 +4,8 @@
             [puppetlabs.services.jruby.puppet-environments :as puppet-env]
             [puppetlabs.services.jruby.jruby-puppet-schemas :as jruby-schemas]
             [puppetlabs.services.jruby.jruby-puppet-internal :as jruby-internal]
-            [schema.core :as schema])
+            [schema.core :as schema]
+            [clojure.tools.logging :as log])
   (:import (com.puppetlabs.puppetserver JRubyPuppet JRubyPuppetResponse PuppetProfiler)
            (org.jruby.embed ScriptingContainer LocalContextScope)
            (puppetlabs.services.jruby.jruby_puppet_schemas JRubyPuppetInstance)
@@ -14,11 +15,13 @@
 ;; Constants
 
 (def ruby-load-path ["./ruby/puppet/lib" "./ruby/facter/lib" "./ruby/hiera/lib"])
+(def gem-home "./target/jruby-gem-home")
 
 (def conf-dir "./target/master-conf")
+(def code-dir "./target/master-code")
 (def var-dir "./target/master-var")
-
-(def gem-home "./target/jruby-gem-home")
+(def run-dir "./target/master-var/run")
+(def log-dir "./target/master-var/log")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; JRubyPuppet Test fixtures
@@ -26,7 +29,7 @@
 (defn with-puppet-conf
   "This function returns a test fixture that will copy a specified puppet.conf
   file into the provided location for testing, and then delete it after the
-  tests have completed. If no destination dir is provided then the puppet.coonf
+  tests have completed. If no destination dir is provided then the puppet.conf
   file is copied to the default location of './target/master-conf'."
   ([puppet-conf-file]
    (with-puppet-conf puppet-conf-file conf-dir))
@@ -49,8 +52,7 @@
   as opposed to a version that has been processed and transformed to comply
   with the JRubyPuppetConfig schema)."
   [pool-config]
-  {:os-settings  {:ruby-load-path ruby-load-path}
-   :product     {:name "puppet-server"
+  {:product     {:name "puppet-server"
                  :update-server-url "http://localhost:11111"}
    :jruby-puppet pool-config
    :certificate-authority {:certificate-status {:client-whitelist []}}})
@@ -64,11 +66,15 @@
   differs slightly from the raw format that would be read from config files
   on disk.)"
   ([]
-   (jruby-core/initialize-config
-     {:jruby-puppet {:gem-home        gem-home
-                     :master-conf-dir conf-dir
-                     :master-var-dir  var-dir}
-      :os-settings  {:ruby-load-path ruby-load-path}}))
+    (jruby-core/initialize-config
+      {:jruby-puppet
+       {:ruby-load-path  ruby-load-path
+        :gem-home        gem-home
+        :master-conf-dir conf-dir
+        :master-code-dir code-dir
+        :master-var-dir  var-dir
+        :master-run-dir  run-dir
+        :master-log-dir  log-dir}}))
   ([options]
    (merge (jruby-puppet-config) options)))
 
@@ -96,7 +102,9 @@
     (handleRequest [_ _]
       (JRubyPuppetResponse. 0 nil nil nil))
     (getSetting [_ _]
-      (Object.))))
+      (Object.))
+    (terminate [_]
+      (log/info "Terminating Master"))))
 
 (schema/defn ^:always-validate
   create-mock-pool-instance :- JRubyPuppetInstance
@@ -104,7 +112,7 @@
    id :- schema/Int
    config :- jruby-schemas/JRubyPuppetConfig
    flush-instance-fn :- IFn
-   profiler :- (schema/maybe PuppetProfiler)]
+   _ :- (schema/maybe PuppetProfiler)]
   (let [instance (jruby-schemas/map->JRubyPuppetInstance
                    {:pool                 pool
                     :id                   id
@@ -114,7 +122,7 @@
                     :jruby-puppet         (create-mock-jruby-instance)
                     :scripting-container  (ScriptingContainer. LocalContextScope/SINGLETHREAD)
                     :environment-registry (puppet-env/environment-registry)})]
-    (.registerLast pool instance)
+    (.put pool instance)
     instance))
 
 (defn mock-pool-instance-fixture
@@ -161,4 +169,3 @@
                   (range size))]
     (fill-drained-pool jrubies)
     result))
-
