@@ -1,11 +1,10 @@
 (ns puppetlabs.services.master.master-core
-  (:import (java.io FileInputStream))
-  (:require [compojure.core :as compojure]
-            [compojure.route :as route]
-            [me.raynes.fs :as fs]
+  (:import (java.io FileInputStream)
+           (clojure.lang IFn))
+  (:require [me.raynes.fs :as fs]
             [puppetlabs.puppetserver.ringutils :as ringutils]
-            [puppetlabs.dujour.version-check :as version-check]
-            [puppetlabs.services.config.puppet-server-config-core :as config]))
+            [puppetlabs.comidi :as comidi]
+            [schema.core :as schema]))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Constants
@@ -20,67 +19,49 @@
 ;;; Routing
 
 (defn v3-routes
-  "Creates the compojure routes to handle the master's '/v3' routes, which
+  "Creates the routes to handle the master's '/v3' routes, which
    includes '/environments' and the non-CA indirected routes. The CA-related
    endpoints are handled separately by the CA service."
   [request-handler]
-  (compojure/routes
-    (compojure/GET "/node/*" request
+  (comidi/routes
+    (comidi/GET ["/node/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/facts/*" request
+    (comidi/GET ["/facts/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/file_content/*" request
+    (comidi/GET ["/file_content/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/file_metadatas/*" request
+    (comidi/GET ["/file_metadatas/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/file_metadata/*" request
+    (comidi/GET ["/file_metadata/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/file_bucket_file/*" request
+    (comidi/GET ["/file_bucket_file/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/PUT "/file_bucket_file/*" request
+    (comidi/PUT ["/file_bucket_file/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/HEAD "/file_bucket_file/*" request
+    (comidi/HEAD ["/file_bucket_file/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/catalog/*" request
+
+    (comidi/GET ["/catalog/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/POST "/catalog/*" request
+    (comidi/POST ["/catalog/" [#".*" :rest]] request
                     (request-handler request))
-    (compojure/PUT "/report/*" request
+    (comidi/PUT ["/report/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/resource_type/*" request
+    (comidi/GET ["/resource_type/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/resource_types/*" request
+    (comidi/GET ["/resource_types/" [#".*" :rest]] request
                    (request-handler request))
-    (compojure/GET "/environments" request
+    (comidi/GET "/environments" request
+                   (request-handler request))
+    (comidi/GET ["/status/" [#".*" :rest]] request
                    (request-handler request))
 
     ;; TODO: when we get rid of the legacy dashboard after 3.4, we should remove
     ;; this endpoint as well.  It makes more sense for this type of query to be
     ;; directed to PuppetDB.
-    (compojure/GET "/facts_search/*" request
+    (comidi/GET ["/facts_search/" [#".*" :rest]] request
                    (request-handler request))))
 
-(defn root-routes
-  "Creates all of the compojure routes for the master."
-  [request-handler]
-  (compojure/routes
-    (compojure/context "/v3" request
-                       (v3-routes request-handler))
-    (route/not-found "Not Found")))
-
-(defn construct-404-error-message
-  [jruby-service product-name]
-  (str "Error: Invalid URL - Puppet Server expects requests that conform to the "
-       "/puppet and /puppet-ca APIs.\n\n"
-       "Note that Puppet 3 agents aren't compatible with this version; if you're "
-       "running Puppet 3, you must either upgrade your agents to match the server "
-       "or point them to a server running Puppet 3.\n\n"
-       "Server Info:\n"
-       "  Puppet Server version: " (version-check/get-version-string (:artifact-id product-name) (:group-id product-name)) "\n"
-       "  Puppet version: " (:puppet-version (config/get-puppet-config jruby-service)) "\n"
-       "  Supported /puppet API versions: " puppet-API-versions "\n"
-       "  Supported /puppet-ca API versions: " puppet-ca-API-versions))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Lifecycle Helper Functions
 
@@ -128,20 +109,42 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
 
-(defn build-ring-handler
-  "Creates the entire compojure application (all routes and middleware)."
+(defn root-routes
+  "Creates all of the web routes for the master."
   [request-handler]
-  {:pre [(fn? request-handler)]}
-  (-> (root-routes request-handler)
+  (comidi/routes
+    (comidi/context "/v3"
+                    (v3-routes request-handler))
+    (comidi/not-found "Not Found")))
+
+(schema/defn ^:always-validate
+  wrap-middleware :- IFn
+  [handler :- IFn
+   puppet-version :- schema/Str]
+  (-> handler
       ringutils/wrap-exception-handling
       ringutils/wrap-request-logging
-      ringutils/wrap-response-logging))
+      ringutils/wrap-response-logging
+      (ringutils/wrap-with-puppet-version-header puppet-version)))
 
-(defn construct-invalid-request-handler
-  "Constructs a ring handler to handle an incorrectly formatted request and indicate to the user
-   they need to update to Puppet 4"
-  [error-message]
-  (fn
-    [_]
-    {:status 404
-     :body   error-message}))
+(schema/defn ^:always-validate get-master-route-config
+  "Get the webserver route configuration for the master service"
+  [master-ns :- schema/Keyword
+   config :- {schema/Keyword schema/Any}]
+  (get-in config [:web-router-service master-ns]))
+
+(schema/defn ^:always-validate
+  get-master-mount :- schema/Str
+  "Get the webserver mount point that the master service is rooted under"
+  [master-ns :- schema/Keyword
+   config-route]
+  (cond
+    (and (map? config-route) (contains? config-route :master-routes))
+    (:master-routes config-route)
+
+    (string? config-route)
+    config-route
+
+    :else
+    (throw (IllegalArgumentException.
+             (str "Route not found for service " master-ns)))))
